﻿"use strict";

angular.module("monApp")
	.controller("CameraController", [
		"$rootScope", "$scope", "$translate",
		function($rootScope, $scope, $translate) {

			$rootScope.chartType = "cam";

			var server = $rootScope.getActiveServer();
			this.ServerId = server.sid;
			this.ServerName = server.sname;

			this.ActiveCamera = $rootScope.getActiveCamera();

			$scope.chartDataSet = [];
			$scope.streamTypeToMbpsTimeSeriesMap = new Map([
				[StreamTypes.Main, []],
				[StreamTypes.Alternative, []],
				[StreamTypes.SecondAlternative, []],
				[StreamTypes.ThirdAlternative, []],
				[StreamTypes.Archive, []],
			]);
			$scope.lastDateTime = new Date();

			var isChartInitTabCameras = false;

			function updateChartDataset(activeCamera) {
				const streamTypeToChartLineSettingsMap = new Map([
					[StreamTypes.Archive, {labelKey: 'CHART_CAM_LINE1', color: "#00FF00"}],
					[StreamTypes.Main, {labelKey: 'CHART_CAM_LINE2', color: "#0000FF"}],
					[StreamTypes.Alternative, {labelKey: 'CHART_CAM_LINE3', color: "#FF0000"}],
					[StreamTypes.SecondAlternative, {labelKey: 'CHART_CAM_LINE4', color: "#FFFF00"}],
					[StreamTypes.ThirdAlternative, {labelKey: 'CHART_CAM_LINE5', color: "#FF00FF"}],
				]);

				let chartDataset = []

				activeCamera.streamsStatuses.forEach((streamStats, streamType) => {
					if (streamStats.IsEnabled) {
						const lineSettings = streamTypeToChartLineSettingsMap.get(streamType);
						const lineLabel = $translate.instant(lineSettings.labelKey);
						const chartData = $scope.streamTypeToMbpsTimeSeriesMap.get(streamType);
						chartDataset.push({label: lineLabel, data: chartData, color: lineSettings.color});
					}
				});

				$scope.chartDataset = chartDataset;
			}

			function updateCameraChart() {

				var activeServer = $rootScope.getActiveServer();

				if ($rootScope.chartType !== "cam")
					return;

				var activeCamera = $rootScope.getActiveCamera();
				$scope.streamTypeToMbpsTimeSeriesMap = activeCamera.streamTypeToMbpsTimeSeriesMap

				if ($('#chart_cam').is(':visible') && activeServer.totalRamMb) {

					if (!isChartInitTabCameras) {

						if ($rootScope.chartType !== "cam")
							return;

						$rootScope.options = getCameraChartOptions($translate);

						updateChartDataset(activeCamera);

						isChartInitTabCameras = true;
					}

					try {
						if ($rootScope.chartType === "cam") {

							updateChartDataset(activeCamera);

							$.plot($("#chart_cam"), $scope.chartDataset, $rootScope.options);
						}
					} catch (e) {

					}
				}

				if ($rootScope.chartType !== "cam")
					return;

				if (!isChartInitTabCameras)
					setTimeout(updateCameraChart, 0);
				else
					setTimeout(updateCameraChart, $rootScope.updateIntervalMs);

			}

			updateCameraChart();
		}
	]);

