﻿"use strict";

function getCameraChartOptions($translate) {

	var options = {
		points: {
			show: true,
			radius: 2
		},
		grid: {
			hoverable: false,
			labelMargin: 15,
			axisMargin: 15
		},
		series: {
			lines: {
				show: true,
				lineWidth: 2,
				fill: false
			}
		},
		ticks: {
			fontSize: 8
		},
		xaxis: {
			mode: "plugin",
			axisLabel: "",
			font: {
				size: 11,
				color: "black"
			},
			ticks: function (axis) {
				var ticks = [];
				var max = axis.max;
				var min = axis.min;

				var diff = max - min;
				var windowWidth = $(window).width();

				//px
				var count = windowWidth / 150;

				var step = diff / count;

				for (var i = 0; i < count; i++) {

					ticks.push(min + i * step);
				}

				return ticks;
			},
			tickFormatter: function (v) {

				var date = new Date(v);

				var hours = date.getHours();
				var minutes = date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes();
				var seconds = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();

				return hours + ":" + minutes + ":" + seconds;
			}
		},
		yaxis:
		{
			min: 0,
			axisLabel: "",
			tickFormatter: function (v) {
				return v.toFixed(1) + $translate.instant('CHART_CAM_YAXIS');
			},
			font: {
				size: 13,
				color: "black"
			},
			margin: {
				right: 50
			}
		},
		legend: {
			labelBoxBorderColor: "#fff"
		}
	};

	return options;
}

function getAdaptersChartOptions($translate) {

	var options = {
		points: {
			show: true,
			radius: 2
		},
		grid: {
			hoverable: false,
			labelMargin: 15,
			axisMargin: 15
		},
		series: {
			lines: {
				show: true,
				lineWidth: 2,
				fill: false
			}
		},
		ticks: {
			fontSize: 8
		},
		xaxis: {
			mode: "plugin",
			axisLabel: "",
			font: {
				size: 11,
				color: "black"
			},
			ticks: function (axis) {
				var ticks = [];
				var max = axis.max;
				var min = axis.min;

				var diff = max - min;
				var windowWidth = $(window).width();

				//px
				var count = windowWidth / 150;

				var step = diff / count;

				for (var i = 0; i < count; i++) {

					ticks.push(min + i * step);
				}

				return ticks;
			},
			tickFormatter: function (v) {

				var date = new Date(v);

				var hours = date.getHours();
				var minutes = date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes();
				var seconds = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();

				return hours + ":" + minutes + ":" + seconds;
			}
		},
		yaxis:
		{
			min: 0,
			axisLabel: "",
			tickFormatter: function (v) {
				return v.toFixed(1) + $translate.instant('CHART_ADAPTER_YAXIS');
			},
			font: {
				size: 13,
				color: "black"
			},
			margin: {
				right: 50
			}
		},
		legend: {
			labelBoxBorderColor: "#fff"
		}
	};

	return options;
}

function getCpuMainChartOptions() {

	var options = {
		points: {
			show: true,
			radius: 2
		},
		grid: {
			hoverable: false,
			labelMargin: 15,
			axisMargin: 15
		},
		series: {
			lines: {
				show: true,
				lineWidth: 2,
				fill: false
			}
		},
		ticks: {
			fontSize: 8
		},
		xaxis: {
			mode: "plugin",
			axisLabel: "",
			font: {
				size: 11,
				color: "black"
			},
			ticks: function (axis) {
				var ticks = [];
				var max = axis.max;
				var min = axis.min;

				var diff = max - min;
				var windowWidth = $(window).width() / 2;

				//px
				var count = windowWidth / 150;

				var step = diff / count;

				for (var i = 0; i < count; i++) {

					ticks.push(min + i * step);
				}

				return ticks;
			},
			tickFormatter: function (v) {

				var date = new Date(v);

				var hours = date.getHours();
				var minutes = date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes();
				var seconds = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();

				return hours + ":" + minutes + ":" + seconds;
			}
		},
		yaxis:
		{
			min: 0,
			max: 100,
			axisLabel: "",
			tickFormatter: function (v) {
				return v + "%";
			},
			font: {
				size: 13,
				color: "black"
			},
			margin: {
				right: 50
			}
		},
		legend: {
			labelBoxBorderColor: "#fff"
		}
	};

	return options;
}

function getCpuChartOptions() {

	var options = {
		points: {
			show: true,
			radius: 2
		},
		grid: {
			hoverable: false,
			labelMargin: 15,
			axisMargin: 15
		},
		series: {
			lines: {
				show: true,
				lineWidth: 2,
				fill: false
			}
		},
		ticks: {
			fontSize: 8
		},
		xaxis: {
			mode: "plugin",
			axisLabel: "",
			font: {
				size: 11,
				color: "black"
			},
			ticks: function (axis) {
				var ticks = [];
				var max = axis.max;
				var min = axis.min;

				var diff = max - min;
				var windowWidth = $(window).width();

				//px
				var count = windowWidth / 150;

				var step = diff / count;

				for (var i = 0; i < count; i++) {

					ticks.push(min + i * step);
				}

				return ticks;
			},
			tickFormatter: function (v) {

				var date = new Date(v);

				var hours = date.getHours();
				var minutes = date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes();
				var seconds = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();

				return hours + ":" + minutes + ":" + seconds;
			}
		},
		yaxis:
		{
			min: 0,
			max: 100,
			axisLabel: "",
			tickFormatter: function (v) {
				return v + "%";
			},
			font: {
				size: 13,
				color: "black"
			},
			margin: {
				right: 50
			}
		},
		legend: {
			labelBoxBorderColor: "#fff"
		}
	};

	return options;
}

function getMemoryChartOptions($translate, activeServer) {

	var options = {
		points: {
			show: true,
			radius: 2
		},
		grid: {
			hoverable: false,
			labelMargin: 15,
			axisMargin: 15
		},
		series: {
			lines: {
				show: true,
				lineWidth: 2,
				fill: false
			}
		},
		ticks: {
			fontSize: 8
		},
		xaxis: {
			mode: "plugin",
			axisLabel: "",
			font: {
				size: 11,
				color: "black"
			},
			ticks: function (axis) {
				var ticks = [];
				var max = axis.max;
				var min = axis.min;

				var diff = max - min;
				var windowWidth = $(window).width();

				//px
				var count = windowWidth / 150;

				var step = diff / count;

				for (var i = 0; i < count; i++) {

					ticks.push(min + i * step);
				}

				return ticks;
			},
			tickFormatter: function (v) {

				var date = new Date(v);

				var hours = date.getHours();
				var minutes = date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes();
				var seconds = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();

				return hours + ":" + minutes + ":" + seconds;
			}
		},
		yaxis:
		{
			min: 0,
			max: (activeServer.totalRamMb / 1024).toFixed(2),
			axisLabel: "",
			tickFormatter: function (v) {
				return v + $translate.instant('CHART_MEM_YAXIS');
			},
			font: {
				size: 13,
				color: "black"
			},
			margin: {
				right: 50
			}
		},
		legend: {
			labelBoxBorderColor: "#fff"
		}
	};

	return options;
}
