﻿"use strict";

angular.module("monApp")

.controller("LogController",
["$scope", "$http", "$location", "$rootScope", "$translate", "$cookies", "$cookieStore",
function ($scope, $http, $location, $rootScope, $translate) {

	$rootScope.chartType = "none";

	$scope.timeFrom = 'last';

	$scope.gridOptions = {
		virtualizationThreshold: 20
	};

	$scope.lastIndex = -1;
	$scope.count = 0;

	$scope.specialEvents = [];

	$scope.selectedServers = [];
	$scope.selectedCams = [];

	$scope.cams = [];
	$scope.servs = [];

	$scope.selectedDay = undefined;
	$scope.selectedMonth = undefined;
	$scope.selectedYear = undefined;

	var locale = $rootScope.activeLocale;

    $scope.logCtrl = this;

    $rootScope.$on('handleBroadcast', function (event, args) {
        //смена языка
	    if (args.message == "langChange") {
	        $scope.logCtrl.apply();
	        $scope.selectedCams[0] = {
	            cid: "00000000-0000-0000-0000-000000000000",
	            cname: $translate.instant('LOG_VIEW.FILTER_NON_CAMERAS'),
	            isSelected: $scope.selectedCams[0].isSelected,
	            isCheckable: true
	        }
	    }
	});

	$("#datetimepicker1").datetimepicker({
		sideBySide: true,
		defaultDate: new Date(),
		showTodayButton: true,
		showClose: false,
		locale: locale,
		format: 'YYYY-MM-DD'
	});

	$("#datetimepicker1").on("dp.change", function () {

		var date = $("#datetimepicker1").data('date');
		

		$scope.selectedDay = String(date).split("-")[2];
		$scope.selectedMonth = String(date).split("-")[1];
		$scope.selectedYear = String(date).split("-")[0];
	});

	$scope.path = $location.protocol() + "://" + $location.host();

	if ($location.port() === 8191 || $location.port() === 8889) {
		$scope.path += ":" + $location.port();
	} else {
		$scope.path += ":" + 8889;
	}

	var camIdx = 0;

	$scope.selectedCams[camIdx] = {
	    cid: "00000000-0000-0000-0000-000000000000",
	    cname: $translate.instant('LOG_VIEW.FILTER_NON_CAMERAS'),
	    isSelected: false,
	    isCheckable: true
	}
	camIdx++;

	for (var i = 0; i < $rootScope.servers.length; i++) {
		var servers1 = $rootScope.servers[i];

		$scope.selectedServers[i] = {
			sid: servers1.sid,
			sname: servers1.sname,
			isSelected: false
		};

		$scope.selectedCams[camIdx] = {
			cid: "00000000-0000-0000-0000-000000000000",
			cname: servers1.sname,
			isSelected: false,
			isCheckable: false
		}
		camIdx++;

		var cameras = servers1.constCameras;
		for (var j = 0; j < cameras.length; j++) {
			var camera = cameras[j];

			$scope.selectedCams[camIdx] = {
				cid: camera.cid,
				cname: camera.cname,
				isSelected: false,
				isCheckable: true
			}

			camIdx++;
		}
	}

	this.loadMore = function () {

		if ($scope.lastIndex === 1)
			return;

		var jsonData = JSON.stringify({
			Cameras: $scope.cams,
			Servers: $scope.servs,
			Count: 30,
			LastIndex: $scope.lastIndex,
			Day: $scope.selectedDay,
			Month: $scope.selectedMonth,
			Year: $scope.selectedYear,
			LanguageLocale: $rootScope.activeLocale
		});

		if ($scope.timeFrom !== 'time')
			jsonData = JSON.stringify({
				Cameras: $scope.cams,
				Servers: $scope.servs,
				Count: 30,
				LastIndex: $scope.lastIndex,
				LanguageLocale: $rootScope.activeLocale
			});

		var reqLog = {
			method: "GET",
			url: $scope.path + "/api/GetWithFilter",
			params: {
				login: $rootScope.login,
				pass: $rootScope.pass,
				jsonData: jsonData,
				rnd: new Date().getTime()

			},
			headers: {
				'Content-Type': undefined
			}
		}

		$http(reqLog)
			.success(function (data) {

				$scope.waitSpecialLog = false;

				if (!data)
					return;

				var newEvents = data;
				if (newEvents.length < 1) {
					return;
				}

				for (var i = 0; i < newEvents.length; i++) {
					var any = false;
					for (var j = 0; j < $scope.specialEvents.length; j++)
						any |= $scope.specialEvents[j].id === newEvents[i].Id;

					if (any)
						continue;

					if (!$scope.specialEvents[$scope.count] || $scope.specialEvents[$scope.count].id !== newEvents[i].Id) {
						$scope.specialEvents[$scope.count] = {};
					}

					if ($scope.lastIndex > newEvents[i].Index)
						$scope.lastIndex = newEvents[i].Index;

					if ($scope.lastIndex === -1)
						$scope.lastIndex = newEvents[i].Index;

					$scope.specialEvents[$scope.count].id = newEvents[i].Id;
					$scope.specialEvents[$scope.count].time = newEvents[i].LocalTime;
					$scope.specialEvents[$scope.count].serverName = newEvents[i].ServerNameAndAddress;
					$scope.specialEvents[$scope.count].descr = newEvents[i].LocalizedMessage;

					$scope.count++;
				}
			})
			.error(function () {
				$scope.waitSpecialLog = false;
			});
	};

	this.apply = function () {

		$scope.lastIndex = -1;

		$scope.count = 0;

		$scope.specialEvents = [];

		$scope.cams = [];
		$scope.servs = [];

		if ($scope.selectedCams.length > 0) {

			for (var i = 0; i < $scope.selectedCams.length; i++) {
				if ($scope.selectedCams[i].isSelected)
					$scope.cams.push($scope.selectedCams[i].cid);
			}
		}

		if ($scope.selectedServers.length > 0) {

			for (var j = 0; j < $scope.selectedServers.length; j++) {
				if ($scope.selectedServers[j].isSelected)
					$scope.servs.push($scope.selectedServers[j].sid);
			}
		}

		if ($scope.cams.length === 0)
			$scope.cams = null;
		if ($scope.servs.length === 0)
			$scope.servs = null;

		this.loadMore();
	};
}]);