﻿"use strict";

angular.module("monApp")

.controller("MainController",
["$rootScope", "$interval", "$routeParams", "$location", "$http", "$scope", "$translate", "$cookies", "$cookieStore",
function ($rootScope, $interval, $routeParams, $location, $http, $scope, $translate, $cookies, $cookieStore) {

	var pass = $cookieStore.get('pass');
	if (!$rootScope.failCount)
		$rootScope.failCount = 0;
	$rootScope.httpTimeout = 10000;
	$rootScope.chartType = "none";
	$rootScope.updateIntervalMs = 2500;
	$rootScope.login = "root";
	$rootScope.totalPoints = 28;
	$scope.temppass = "";

	if (!$rootScope.timerFunc)
		$rootScope.timerFunc = function () {
			var path = $location.protocol() + "://" + $location.host();

			if ($location.port() === 8191 || $location.port() === 8889) {
				path += ":" + $location.port();
			} else {
				path += ":" + 8889;
			}

			if ($rootScope.waitJsonInfo !== true) {

				$rootScope.waitJsonInfo = true;

				var reqInfo = {
					method: "GET",
					url: path + "/api/GetAllInfo",
					headers: {
						'Content-Type': undefined
					},
					params: {
						login: $rootScope.login,
						pass: $rootScope.pass,
						rnd: new Date().getTime()
					},
					timeout: $rootScope.httpTimeout
				}

				$http(reqInfo)
					.success(function (data) {

						$rootScope.failCount = 0;
						$rootScope.waitJsonInfo = false;

						if (!data) {
							return;
						}

						var newServers = data.Servers;
						if (!newServers) {

							$rootScope.servers = null;
							return;
						}

						if (!$rootScope.servers || $rootScope.servers.length !== newServers.length) {
							$rootScope.servers = [];
						}

						var servers = $rootScope.servers;

						for (var i = 0; i < newServers.length; i++) {
							if (!servers[i] || servers[i].sid !== newServers[i].ServerId) {
								servers[i] = {};
							}

							var newServer = newServers[i];
							var server = servers[i];

							fillServer(server, newServer, $rootScope.totalPoints);
						}
					})
					.error(function (err) {
						$rootScope.waitJsonInfo = false;
						if ($rootScope.pass)
							$rootScope.failCount++;
					});
			}

			if ($rootScope.waitJsonLog !== true) {

				$rootScope.waitJsonLog = true;

				var jsonData = JSON.stringify(
				{
					Count: "5",
					LanguageLocale: $rootScope.activeLocale
				});

				var reqLog = {
					method: "GET",
					url: path + "/api/GetWithFilter",
					headers: {
						'Content-Type': undefined
					},
					params: {
						login: $rootScope.login,
						pass: $rootScope.pass,
						jsonData: jsonData,
						rnd: new Date().getTime()
					},
					timeout: $rootScope.httpTimeout
				}

				$http(reqLog)
					.success(function (data) {

						$rootScope.waitJsonLog = false;

						if (!data)
							return;

						var newEvents = data;
						if (newEvents.length < 1) {

							$rootScope.events = null;
							return;
						}

						if (!$rootScope.events || $rootScope.events.length !== newEvents.length)
							$rootScope.events = [];

						var events = $rootScope.events;

						for (var i = 0; i < newEvents.length; i++) {
							if (!events[i] || events[i].id !== newEvents[i].Id) {
								events[i] = {};
							}

							events[i].id = newEvents[i].Id;
							events[i].time = newEvents[i].LocalTime;
							events[i].serverName = newEvents[i].ServerNameAndAddress;
							events[i].descr = newEvents[i].LocalizedMessage;

						}
					})
					.error(function () {
						$rootScope.waitJsonLog = false;
					});
			}
		};

	if (!$rootScope.timer)
		$rootScope.timer = $interval(function () {
			$rootScope.timerFunc();
		}, $rootScope.updateIntervalMs);


	if (pass) {
		var path1 = $location.protocol() + "://" + $location.host();

		if ($location.port() === 8191 || $location.port() === 8889) {
			path1 += ":" + $location.port();
		} else {
			path1 += ":" + 8889;
		}

		var reqSet = {
			method: "GET",
			url: path1 + "/api/CheckAuthInfo",
			params: {
				login: $rootScope.login.toString(),
				pass: pass.toString(),
				rnd: new Date().getTime()

			},
			headers: {
				'Content-Type': undefined
			}
		}

		$http(reqSet)
			.success(function () {

				$rootScope.pass = pass;

				$rootScope.timerFunc();
			})
			.error(function () {
			});
	}

	if (!$rootScope.getActiveServer)
		$rootScope.getActiveServer = function () {

			var id = $routeParams["id"];
			var servers = $rootScope.servers;
			for (var i = 0; i < servers.length; i++) {

				if (servers[i].sid === id)
					return servers[i];
			}

			return null;
		};

	if (!$rootScope.getActiveCamera)
		$rootScope.getActiveCamera = function () {

			var camid = $routeParams["camid"];

			for (var i = 0; i < $rootScope.servers.length; i++) {
				var cams = $rootScope.servers[i].cameras;
				for (var j = 0; j < cams.length; j++) {
					if (cams[j].cid === camid)
						return cams[j];
				}
			}

			return null;
		};

	if (!$rootScope.getActiveAdapter)
		$rootScope.getActiveAdapter = function () {

			var serverid = $routeParams["id"];

			var adapterid = $routeParams["adapterid"];

			for (var i = 0; i < $rootScope.servers.length; i++) {
				var adapters = $rootScope.servers[i].adapters;
				for (var j = 0; j < adapters.length; j++) {
					if (serverid === $rootScope.servers[i].sid && j === parseInt(adapterid))
						return adapters[j];
				}
			}

			return null;
		};

	if (!$scope.goTo)
		$scope.goTo = function (id) {
			$location.path("/server/" + id);
		};

	if (!this.comeIn)
		this.comeIn = function () {

			var path1 = $location.protocol() + "://" + $location.host();

			if ($location.port() === 8191 || $location.port() === 8889) {
				path1 += ":" + $location.port();
			} else {
				path1 += ":" + 8889;
			}

			$scope.loginError = false;

			var reqSet = {
				method: "GET",
				url: path1 + "/api/CheckAuthInfo",
				params: {
					login: $rootScope.login.toString(),
					pass: sha1($scope.temppass).toString(),
					rnd: new Date().getTime()

				},
				headers: {
					'Content-Type': undefined
				}
			}

			$http(reqSet)
				.success(function () {

					$rootScope.pass = sha1($scope.temppass);

					$cookieStore.put('pass', sha1($scope.temppass));

					$rootScope.timerFunc();
				})
				.error(function () {

					$scope.loginError = true;
				});

		};
}
]);