﻿"use strict";

function fillServer(server, newServer, maxCount) {

	if (!server.cpu) {
		server.cpu = [];
	}
	if (!server.mem) {
		server.mem = [];
	}
	if (!server.servCpu) {
		server.servCpu = [];
	}
	if (!server.servMem) {
		server.servMem = [];
	}
	if (!server.cameras)
		server.cameras = [];
	if (!server.constCameras)
		server.constCameras = [];
	var serverCameras = server.cameras;

	if (!server.clients)
		server.clients = [];

	if (!server.adapters)
		server.adapters = [];
	var serverAdapters = server.adapters;

	var totalPoints = maxCount;

	server.sname = newServer.ServerName;
	server.surl = newServer.ServerUrl;
	server.sid = newServer.ServerId;
	server.timeLocalStr = newServer.LocalTime;
	server.Problems = newServer.Problems;

	var now = new Date(server.timeLocalStr).getTime();

	var constCameras = newServer.Cameras;
	if (!constCameras)
		constCameras = [];

	fillConstCameras(server.constCameras, constCameras);

	if (!newServer.ComputerInfo) {
		server.isAgentWorking = false;
		server.isWorking = false;
		return;
	}

	server.isAgentWorking = true;
	server.computerCpu = GetNotNullValue(newServer.ComputerInfo.Cpu);
	server.computerRamMb = GetNotNullValue(newServer.ComputerInfo.RamMb);
	server.totalRamMb = GetNotNullValue(newServer.ComputerInfo.TotalRamMb);

	//cpu
	var lastValTime = new Date();
	if (server.cpu.length > 0)
		lastValTime = new Date(server.cpu[server.cpu.length - 1][0]);

	if (lastValTime.getTime() !== now)
		server.cpu.push([now, GetNotNullValue(newServer.ComputerInfo.Cpu)]);

	if (server.cpu.length > totalPoints) {
		server.cpu.shift();
	}

	//mem
	lastValTime = new Date();
	if (server.mem.length > 0)
		lastValTime = new Date(server.mem[server.mem.length - 1][0]);

	if (lastValTime.getTime() !== now)
		server.mem.push([now, GetNotNullValue(newServer.ComputerInfo.RamMb)]);

	if (server.mem.length > totalPoints) {
		server.mem.shift();
	}

	var newAdapters = newServer.ComputerInfo.Adapters;
	if (!newAdapters)
		newAdapters = [];
	fillServerAdapters(serverAdapters, newAdapters, totalPoints, now);

	if (!newServer.ServerInfo) {
		server.isWorking = false;
		return;
	}

	server.isWorking = true;
	server.version = newServer.ServerInfo.ServerVersion;
	server.serverCpu = GetNotNullValue(newServer.ServerInfo.Cpu);
	server.serverRam = GetNotNullValue(newServer.ServerInfo.RamMb);
	server.uptimeHours = GetNotNullValue(newServer.ServerInfo.UptimeHours);
	server.serverEdition = newServer.ServerInfo.ServerEdition;
	server.archiveSizeMb = GetNotNullValue(newServer.ServerInfo.ArchiveSizeMb);
	server.archiveWriteSpeedMBps = GetNotNullValue(newServer.ServerInfo.ArchiveWriteSpeedMBps);
	server.archiveDepthDays = GetNotNullValue(newServer.ServerInfo.ArchiveDepthDays);
	server.isReplicationServer = newServer.ServerInfo.IsReplicationServer;

	//servCpu
	lastValTime = new Date();
	if (server.servCpu.length > 0)
		lastValTime = new Date(server.servCpu[server.servCpu.length - 1][0]);

	if (lastValTime.getTime() !== now)
		server.servCpu.push([now, GetNotNullValue(newServer.ServerInfo.Cpu)]);

	if (server.servCpu.length > totalPoints) {
		server.servCpu.shift();
	}

	//servMem
	lastValTime = new Date();
	if (server.servMem.length > 0)
		lastValTime = new Date(server.servMem[server.servMem.length - 1][0]);

	if (lastValTime.getTime() !== now)
		server.servMem.push([now, GetNotNullValue(newServer.ServerInfo.RamMb)]);

	if (server.servMem.length > totalPoints) {
		server.servMem.shift();
	}

	var serverProblems = newServer.ServerInfo.Problems;
	if (IsServerContainsProblems(serverProblems)) {
		server.problemsDetected = true;
		server.LicenseProblem = serverProblems.LicenseProblem;
		server.NoConfigSynchronization = serverProblems.NoConfigSynchronization;
		server.SubSystemsOverload = serverProblems.SubSystemsOverload;
		server.ArchiveErrors = serverProblems.ArchiveErrors;
		server.ReservedModeActivated = serverProblems.ReservedModeActivated;
	} 
	else {
		server.problemsDetected = false;
		server.LicenseProblem = null;
		server.NoConfigSynchronization = null;
		server.SubSystemsOverload = null;
		server.ArchiveErrors = null;
		server.ReservedModeActivated = null;
	}

	var newCameras = newServer.ServerInfo.Cameras;
	if (!newCameras)
		newCameras = [];

	fillServerCameras(serverCameras, newCameras, totalPoints, now);

	var cameraProblems = 0;

	for (var camI = 0; camI < serverCameras.length; camI++) {
		if (IsErrorCamera(serverCameras[camI]))
			cameraProblems++;
	}

	if (cameraProblems > 0) {
		server.problemsDetected = true;
		server.CameraProblems = cameraProblems;
	}

	server.nonErrorCameras = function () {
		var cnt = 0;
		for (var k = 0; k < serverCameras.length; k++) {
			if (!IsErrorCamera(serverCameras[k]))
				cnt++;
		}
		return cnt;
	};

	fillClients(server.clients, newServer.ServerInfo.Clients);
}

function fillClients(serverClients, newClients) {

	if (newClients.length < 1) {
		serverClients.splice(0, serverClients.length);
	} else {
		var j = 0;
		var i = 0;
		var any = false;

		var indexToDelete = [];
		for (j = 0; j < serverClients.length; j++) {
			any = false;
			for (i = 0; i < newClients.length; i++)
				any |= serverClients[j].ip === newClients[i].ip && serverClients[j].user === newClients[i].user;
			if (!any)
				indexToDelete.push(j);
		}
		for (j = 0; j < indexToDelete.length; j++)
			serverClients.splice(indexToDelete[j] - j, 1);

		for (j = 0; j < newClients.length; j++) {
			any = false;
			for (i = 0; i < serverClients.length; i++)
				any |= serverClients[i].ip === newClients[j].ip && serverClients[i].user === newClients[j].user;

			if (!any) {
				var client = {};
				client.ip = newClients[j].Ip;
				client.user = newClients[j].User;
				client.clientType = newClients[j].clientType;
				serverClients.push(client);
			}
		}


		for (j = 0; j < newClients.length; j++) {
			var newCamera = newClients[j];

			for (i = 0; i < serverClients.length; i++) {
				var oldClient = serverClients[i];
				if (oldClient.ip !== newCamera.ip && oldClient.user !== newCamera.user)
					continue;

				oldClient.ip = newCamera.Ip;
				oldClient.user = newCamera.User;

				break;
			}
		}
	}
}

function fillServerCameras(serverCameras, newCameras, totalPoints, now) {

	if (newCameras.length < 1) {
		serverCameras.splice(0, serverCameras.length);
	} else {
		var j = 0;
		var i = 0;
		var any = false;

		var indexToDelete = [];
		for (j = 0; j < serverCameras.length; j++) {
			any = false;
			for (i = 0; i < newCameras.length; i++)
				any |= serverCameras[j].cid === newCameras[i].Id;
			if (!any)
				indexToDelete.push(j);
		}
		for (j = 0; j < indexToDelete.length; j++)
			serverCameras.splice(indexToDelete[j] - j, 1);

		for (j = 0; j < newCameras.length; j++) {
			any = false;
			for (i = 0; i < serverCameras.length; i++)
				any |= serverCameras[i].cid === newCameras[j].Id;

			if (!any) {
				var cam = {};
				cam.cid = newCameras[j].Id;
				cam.streamTypeToMbpsTimeSeriesMap = new Map([
					[StreamTypes.Main, []],
					[StreamTypes.Alternative, []],
					[StreamTypes.SecondAlternative, []],
					[StreamTypes.ThirdAlternative, []],
					[StreamTypes.Archive, []],
				]);

				serverCameras.push(cam);
			}
		}


		for (j = 0; j < newCameras.length; j++) {
			var newCamera = newCameras[j];

			for (i = 0; i < serverCameras.length; i++) {
				var oldCamera = serverCameras[i];
				if (oldCamera.cid !== newCamera.Id)
					continue;

				oldCamera.cname = newCamera.Name;
				oldCamera.Status = newCamera.Status;

				const isNewStreamsStatisticsFormat = newCamera.StreamsStatuses != null;
				if (isNewStreamsStatisticsFormat) {
					oldCamera.streamsStatuses = new Map([
						[StreamTypes.Archive, {IsEnabled: true, VideoMbps: newCamera.WriteVideoMbps}],
						[StreamTypes.Main, newCamera.StreamsStatuses.Main],
						[StreamTypes.Alternative, newCamera.StreamsStatuses.Alternative],
						[StreamTypes.SecondAlternative, newCamera.StreamsStatuses.SecondAlternative],
						[StreamTypes.ThirdAlternative, newCamera.StreamsStatuses.ThirdAlternative],
					]);
				} else {
					oldCamera.streamsStatuses = new Map([
						[StreamTypes.Archive, {IsEnabled: true, VideoMbps: newCamera.WriteVideoMbps}],
						[StreamTypes.Main, {IsEnabled: true, VideoMbps: newCamera.ReceiveVideoMbps}],
						[StreamTypes.Alternative,
							{IsEnabled: newCamera.AltEnabled, VideoMbps: newCamera.ReceiveAltVideoMbps}],
						[StreamTypes.SecondAlternative, {IsEnabled: false, VideoMbps: 0.0}],
						[StreamTypes.ThirdAlternative, {IsEnabled: false, VideoMbps: 0.0}],
					]);
				}

				//camera info
				var lastValTime = new Date();
				const anyTimeSeries = oldCamera.streamTypeToMbpsTimeSeriesMap.values().next().value;
				if (anyTimeSeries != null && anyTimeSeries.length > 0)
					lastValTime = new Date(anyTimeSeries[anyTimeSeries.length - 1][0]);

				if (lastValTime.getTime() !== now) {
					oldCamera.streamTypeToMbpsTimeSeriesMap.forEach((streamStats, streamType) => {
						const streamStatus = oldCamera.streamsStatuses.get(streamType);
						const videoMbps = streamStatus.IsEnabled ? streamStatus.VideoMbps : undefined;
						oldCamera.streamTypeToMbpsTimeSeriesMap.get(streamType).push([now, videoMbps]);
					});
				}
				break;
			}
		}

		for (i = 0; i < serverCameras.length; i++) {
			var camera = serverCameras[i];
			camera.streamTypeToMbpsTimeSeriesMap.forEach((streamRates, streamType) => {
				if (streamRates.length > totalPoints)
					camera.streamTypeToMbpsTimeSeriesMap.get(streamType).shift();
			});
		}
	}
}

function fillServerAdapters(serverAdapters, newAdapters, totalPoints, now) {
	if (newAdapters && newAdapters.length > 0) {

		var j = 0;
		var i = 0;
		var any = false;

		var indexToDelete = [];
		for (j = 0; j < serverAdapters.length; j++) {
			any = false;
			for (i = 0; i < newAdapters.length; i++)
				any |= serverAdapters[j].name === newAdapters[i].Name;
			if (!any)
				indexToDelete.push(j);
		}
		for (j = 0; j < indexToDelete.length; j++)
			serverAdapters.splice(indexToDelete[j] - j, 1);

		for (j = 0; j < newAdapters.length; j++) {
			any = false;
			for (i = 0; i < serverAdapters.length; i++)
				any |= serverAdapters[i].name === newAdapters[j].Name;

			if (!any) {
				var aName = newAdapters[i].Name;
				var aCurrentMbps = 0;
				var aMaxMbps = 0;
				if (newAdapters[i].Current && newAdapters[i].Current > 0.0)
					aCurrentMbps = newAdapters[i].Current;
				if (newAdapters[i].Max && newAdapters[i].Max > 0.0)
					aMaxMbps = newAdapters[i].Max;

				var ad = {
					name: aName,
					currentMbps: aCurrentMbps,
					maxMbps: aMaxMbps,
					load: []
				};
				serverAdapters.push(ad);
			}
		}

		for (j = 0; j < newAdapters.length; j++) {
			var newAdapter = newAdapters[j];

			for (i = 0; i < serverAdapters.length; i++) {
				var oldAdapter = serverAdapters[i];
				if (oldAdapter.name !== newAdapter.Name)
					continue;

				var aName = newAdapter.Name;
				var aCurrentMbps = 0;
				var aMaxMbps = 0;
				if (newAdapter.Current && newAdapter.Current > 0.0)
					aCurrentMbps = newAdapter.Current;
				if (newAdapter.Max && newAdapter.Max > 0.0)
					aMaxMbps = newAdapter.Max;

				oldAdapter.name = aName;
				oldAdapter.currentMbps = aCurrentMbps;
				oldAdapter.maxMbps = aMaxMbps;

				//camera info
				var lastValTime = new Date();
				if (oldAdapter.load.length > 0)
					lastValTime = new Date(oldAdapter.load[oldAdapter.load.length - 1][0]);

				if (lastValTime.getTime() !== now)
					oldAdapter.load.push([now, GetNotNullValue(aCurrentMbps)]);

				break;
			}
		}

		for (i = 0; i < serverAdapters.length; i++) {
			var adapter = serverAdapters[i];
			if (adapter.load.length > totalPoints)
				adapter.load.shift();
		}
	}
}

function fillConstCameras(serverConstCameras, newConstCameras) {
	if (newConstCameras.length < 1) {
		serverConstCameras.splice(0, serverConstCameras.length);
	} else {
		var j = 0;
		var i = 0;
		var any = false;

		var indexToDelete = [];
		for (j = 0; j < serverConstCameras.length; j++) {
			any = false;
			for (i = 0; i < newConstCameras.length; i++)
				any |= serverConstCameras[j].cid === newConstCameras[i].Id;
			if (!any)
				indexToDelete.push(j);
		}
		for (j = 0; j < indexToDelete.length; j++)
			serverConstCameras.splice(indexToDelete[j] - j, 1);

		for (j = 0; j < newConstCameras.length; j++) {
			any = false;
			for (i = 0; i < serverConstCameras.length; i++)
				any |= serverConstCameras[i].cid === newConstCameras[j].Id;

			if (!any) {
				var cam = {};
				cam.cid = newConstCameras[j].Id;
				cam.cname = newConstCameras[j].Name;
				serverConstCameras.push(cam);
			}
		}


		for (j = 0; j < newConstCameras.length; j++) {
			var newCamera = newConstCameras[j];

			for (i = 0; i < serverConstCameras.length; i++) {
				var oldCamera = serverConstCameras[i];
				if (oldCamera.cid !== newCamera.Id)
					continue;

				oldCamera.cname = newCamera.Name;
				break;
			}
		}
	}
}

function GetNotNullValue(data) {
	return data || 0;
}
